%define anolis_release 1
Name:           augeas
Version:        1.14.2
Summary:        A library for changing configuration files
License:        LGPL-2.0-or-later AND LGPL-2.1-only AND LGPL-2.1-or-later AND (GPL-3.0-or-later WITH Bison-exception-2.2) AND Kazlib AND GPL-2.0-or-later AND BSD-2-Clause AND LicenseRef-Fedora-Public-Domain

%global forgeurl https://github.com/hercules-team/%{name}
%global commit 2de06e0519bb8daf047191e46a9672e1d16b1955
%forgemeta

Release:        %{anolis_release}%{?dist}
URL:            %{forgeurl}
Source0:        %{forgesource}

# The problem with packaging from the upstream git repo is that we
# need to provide our own gnulib submodule.  I created this by doing:
# git archive --format=tar --prefix=.gnulib/ HEAD | gzip -9 > gnulib-2f7479a16a.tar.gz
Source1:        gnulib-2f7479a16a.tar.gz
Provides:       bundled(gnulib)

BuildRequires:  autoconf, automake, libtool
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  readline-devel
BuildRequires:  libselinux-devel
BuildRequires:  libxml2-devel
BuildRequires:  bash-completion

Requires:       %{name}-libs = %{version}-%{release}

%description
A library for programmatically editing configuration files. Augeas parses
configuration files into a tree structure, which it exposes through its
public API. Changes made through the API are written back to the initially
read files.

The transformation works very hard to preserve comments and formatting
details. It is controlled by ``lens'' definitions that describe the file
format and the transformation into a tree.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        libs
Summary:        Libraries for %{name}

%description    libs
The libraries for %{name}.

Augeas is a library for programmatically editing configuration files. It parses
configuration files into a tree structure, which it exposes through its
public API. Changes made through the API are written back to the initially
read files.

%package        static
Summary:        Static libraries for %{name}
Requires:       %{name}-devel = %{version}-%{release}

%description    static
The %{name}-static package contains static libraries needed to produce
static builds using %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name}-libs = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package bash-completion
Summary:       Bash tab-completion for %{name}
BuildArch:     noarch
Requires:      bash-completion >= 2.0
# Don't use _isa here because it's a noarch package.  This dependency
# is just to ensure that the subpackage is updated along with augeas.
Requires:      %{name} = %{version}-%{release}


%description bash-completion
Install this package if you want intelligent bash tab-completion
for %{name}.


%prep
%forgeautosetup -p1
zcat %{SOURCE1} | tar xf -

# Copied from upstream ./bootstrap:
modules='argz fnmatch getline getopt-gnu gitlog-to-changelog
canonicalize-lgpl isblank locale mkstemp regex safe-alloc selinux-h
stpcpy stpncpy strchrnul strndup sys_wait vasprintf'
.gnulib/gnulib-tool             \
  --lgpl=2                      \
  --with-tests                  \
  --m4-base=gnulib/m4           \
  --source-base=gnulib/lib      \
  --tests-base=gnulib/tests     \
  --aux-dir=build/ac-aux        \
  --libtool                     \
  --quiet                       \
  --import $modules

autoreconf -fiv


%build
%configure \
%ifarch riscv64
    --disable-gnulib-tests \
%endif
    --enable-static
# Disable _smp_mflags because parallel tests fail with the git version
# because it tries to run lex and yacc in parallel even though lex
# depends on parser.h from yacc.
# https://github.com/hercules-team/augeas/issues/572
#make %%{?_smp_mflags}
make


%check
# Disable test-preserve.sh SELinux testing. This fails when run under mock due
# to differing SELinux labelling.
export SKIP_TEST_PRESERVE_SELINUX=1

make %{?_smp_mflags} check || {
  echo '===== tests/test-suite.log ====='
  cat tests/test-suite.log
  exit 1
}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="%{__install} -p"
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

# The tests/ subdirectory contains lenses used only for testing, and
# so it shouldn't be packaged.
rm -r $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/dist/tests

# In 1.9.0, the example /usr/bin/dump gets installed inadvertently
rm -f $RPM_BUILD_ROOT/usr/bin/dump

%ldconfig_scriptlets libs

%files
%{_bindir}/augmatch
%{_bindir}/augparse
%{_bindir}/augprint
%{_bindir}/augtool
%{_bindir}/fadot
%doc %{_mandir}/man1/*
%{_datadir}/vim/vimfiles/syntax/augeas.vim
%{_datadir}/vim/vimfiles/ftdetect/augeas.vim

%files libs
# _datadir/augeas and _datadir/augeas/lenses are owned
# by filesystem.
%{_datadir}/augeas/lenses/dist
%{_libdir}/*.so.*

%files devel
%doc
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/augeas.pc

%files static
%{_libdir}/libaugeas.a
%{_libdir}/libfa.a

%files doc
%doc AUTHORS NEWS INSTALL

%files bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/augmatch
%{_datadir}/bash-completion/completions/augprint
%{_datadir}/bash-completion/completions/augtool

%changelog
* Mon Feb 24 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 1.14.2-1
- Refer to CentOS Stream augeas-1.14.2-0.2.20240909git2de06e0 (tdawson@redhat.com)

* Wed Dec 27 2023 happy_orange <songnannan@linux.alibaba.com> - 1.13.0-6
- fix the source error

* Fri Apr 14 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.13.0-5
- Optimize the spec file

* Mon Apr 03 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.13.0-4
- remove unnecessary BuildRequires

* Fri Feb 10 2023 happy_orange <songnannan@linux.alibaba.com> - 1.13.0-3
- add generate compatibility scripts

* Thu Sep 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.13.0-2
- add doc package

* Thu Apr 14 2022 yuanhui <yuanhui@linux.alibaba.com> - 1.13.0-1
- Init augeas for anolis os 23
